﻿using System;
using System.Numerics;
using Dalamud.Interface.Windowing;
using ImGuiNET;

namespace DalamudShock.Windows
{
    public class ConfigWindow : Window, IDisposable
    {
        private Configuration Configuration;
        public ConfigWindow(Plugin plugin) : base("DalamudShock Config###With a constant ID")
        {
            Flags = ImGuiWindowFlags.NoResize | ImGuiWindowFlags.NoCollapse | ImGuiWindowFlags.NoScrollbar |
                    ImGuiWindowFlags.NoScrollWithMouse;
            Size = new Vector2(600, 400); 
            SizeCondition = ImGuiCond.Always;
            Configuration = plugin.Configuration;
        }

        public void Dispose() { }

        public override void PreDraw()
        {
            if (Configuration.IsConfigWindowMovable)
            {
                Flags &= ~ImGuiWindowFlags.NoMove;
            }
            else
            {
                Flags |= ImGuiWindowFlags.NoMove;
            }
        }

        public override void Draw()
        {
            var apiKey = Configuration.openshockApiKey;
            if (ImGui.InputText("OpenShock API Key", ref apiKey, 100))
            {
                Configuration.openshockApiKey = apiKey;
            }

            var shockerID = Configuration.OpenshockShockerID;
            if (ImGui.InputText("OpenShock Shocker ID", ref shockerID, 100))
            {
                Configuration.OpenshockShockerID = shockerID;
            }
            var maxShock = Configuration.MaxValue;
            if (ImGui.SliderInt("Intensity cap", ref maxShock, 0, 100))
            {
                Configuration.MaxValue = maxShock;
            }
            var maxLength = Configuration.MaxDuration;
            if (ImGui.SliderInt("Duration Cap (sec)", ref maxLength, 1, 30)) 
            {
                // Map the value from [1, 30] to [1000, 30000]
                Configuration.MaxDuration = MapValue(maxLength, 1, 30, 1000, 30000);
            }
            int MapValue(int value, int fromMin, int fromMax, int toMin, int toMax)
            {
                return (int)((float)(value - fromMin) / (fromMax - fromMin) * (toMax - toMin) + toMin);
            }
            bool isVibrationAllowed = Configuration.IsVibrationAllowed;
            if (ImGui.Checkbox("Allow Vibration", ref isVibrationAllowed)) 
            {
                Configuration.IsVibrationAllowed = isVibrationAllowed;
            }
            ImGui.Spacing();
            if (ImGui.Button("Save Configuration"))
            {
                Configuration.Save();
            }
        }
    }
}
